//<c>   Copyright 1997-1999 by Gerry J. Danen; all rights reserved.

//<t>   Doomsday Clock

//      /Q or /QUIET reduces output
//      /NT or /NOTIME changes the output format

#include"gd_tools.h"


#define pgVERS_ "V2.20"
#define pgTITL_ "Doomsday Clock"
#define pgCOPR_ "1997"


BOOL    ynQuiet = FALSE, ynTime = TRUE ;
INT32   nTargetDate = 20000101L, nSystemDate ;
char    sTargetDate[] = "January 1, 2000" ;


INT32   get_system_date( void )
{
    INT16       y, m, d ;

    if ( dt_getsystemdate( &nSystemDate, &y, &m, &d ) != OK )
    {
        printf( "Illegal system date\n" );
        exit( BAD_EXIT );
    }
    if ( y < 1999 || y > 2000 )
    {
        printf( "Irrelevant system date. Must be 1999.\n" );
        exit( BAD_EXIT );
    }
    return( DaysBetween( nSystemDate, nTargetDate ) );
}


long    get_system_time( void )
{
    INT16       hh, mm, ss, tt ;
    INT32       hmst, tics ;

    if ( tm_getsystemtime( &hmst, &tics, &hh, &mm, &ss, &tt ) != OK )
    {
        printf( "Illegal system time\n" );
        exit( BAD_EXIT );
    }
    return( ((long)hh * 3600L) + ((long)mm * 60L) + ss );
}


void    main( int argc, char *argv[] )
{
    int         i ;
    long        years, days, hours, minutes, seconds ;
    INT32       days2go ;

    tt_init( SHAREWARE_VERSION, 0, pgVERS_, pgTITL_, pgCOPR_ );

    argc -= 1 ;
    LOOP( i, 1, argc, 1 )                       // process arguments
    {
        if ( st_eq( argv[i], "/quiet") ||
             st_eq( argv[i], "/q"    ) ||
             st_eq( argv[i], "quiet" ) ||
             st_eq( argv[i], "q"     ) )
            ynQuiet = TRUE ;
        if ( st_eq( argv[i], "/notime") ||
             st_eq( argv[i], "/nt"    ) ||
             st_eq( argv[i], "notime" ) ||
             st_eq( argv[i], "nt"     ) )
            ynTime = FALSE ;
    }
    if ( ! ynQuiet )
        logon(0);

    days2go = get_system_date();

    if ( nSystemDate == nTargetDate )
    {
        printf( "Today is %s!", sTargetDate );
        if ( ! ynQuiet )
            printf( "\n" );
        exit( GOOD_EXIT );
    }

    if ( nSystemDate < nTargetDate )
    {
        long dif, now, midnight = (24L * 60L * 60L) ;

        now     = get_system_time();
        dif     = midnight - now - 1 ;
        hours   = dif / 3600 ;
        dif     = dif - (hours * 3600) ;
        minutes = dif / 60 ;
        seconds = dif - (minutes * 60) ;

        if ( ynTime )
            days2go -= 1 ;                      // not a full day, as we're showing time now...
        years = (int)(days2go / 365L);
        days  = days2go - (years * 365);
        if ( ynTime )
        {
            if ( years )
                printf( "%ld year%s, ", years, ONE_OR_MORE(years) );
            printf( "%ld day%s, "
                    "%ld hour%s, %ld minute%s, and %ld second%s until %s.",
                    days   , ONE_OR_MORE(days   ),
                    hours  , ONE_OR_MORE(hours  ),
                    minutes, ONE_OR_MORE(minutes),
                    seconds, ONE_OR_MORE(seconds), sTargetDate );
        }
        else
        {
            if ( years )
                printf( "%ld year%s and ", years, ONE_OR_MORE(years) );
            printf( "%ld day%s until %s.",
                    days, ONE_OR_MORE(days), sTargetDate );
        }
        if ( ! ynQuiet )
            printf( "\n" );
        if ( (ynTime && days2go == 0) || ((!ynTime) && days2go == 1) )
            printf( "\nTomorrow is the big day!\n\n" );
    }
    else
        printf( "We've already passed the magic moment...\n" );

    exit( GOOD_EXIT );
}
